@@ -1,4 +1,5 @@
 from rest_framework import status
+from rest_framework import serializers
 from rest_framework.response import Response
 
 
@@ -22,3 +23,7 @@ def raise_required_key(key):
     return Response(
         status=status.HTTP_400_BAD_REQUEST, data={key: "this key is required."}
     )
+
+
+def raise_validation_error(key):
+    raise serializers.ValidationError({key: "This field is required."})
